package com.hindigk.gkhindiquiz.hindiquiz.activities;

import android.content.DialogInterface;
import android.content.Intent;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.text.InputType;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdView;
import com.hindigk.gkhindiquiz.hindiquiz.R;
import com.hindigk.gkhindiquiz.hindiquiz.SqliteDatabaseHelper.DatabaseHelper;
import com.hindigk.gkhindiquiz.hindiquiz.model.AllDBDataModel;
import com.hindigk.gkhindiquiz.hindiquiz.utils.Constants;

import java.io.IOException;
import java.util.List;

public class QuestionAnswerActivity extends AppCompatActivity implements View.OnClickListener {

    private DatabaseHelper mainDB;
    private Button answerA, answerB, answerC, answerD, gotoBtn;
    private TextView questionText;
    private List<AllDBDataModel> allDBData;
    private int queNoCounter;

    private boolean isAnsBtnClicked;
    private ImageView prevImage, nextImage;
    private TextView questionNoText;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_question_answer);

        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
            getSupportActionBar().setTitle("GK");
        }

        int catIndex = getIntent().getIntExtra("cat_index",0);
        int sunCatIndex = getIntent().getIntExtra("sub_cat_index",0);

        if (catIndex == 0){
            getSupportActionBar().setTitle("GK - "+Constants.gkSubCatNameList[sunCatIndex]);
            Constants.DATABASE_NAME = Constants.gkSubCatDbList[sunCatIndex];
        } else if (catIndex == 1){
            getSupportActionBar().setTitle("Reasoning - "+Constants.reasoningSubCatNameList[sunCatIndex]);
            Constants.DATABASE_NAME = Constants.reasoningSubCatDbList[sunCatIndex];
        }else {
            getSupportActionBar().setTitle(Constants.mainCatNameList[catIndex]);
            Constants.DATABASE_NAME = Constants.mainCatDbList[catIndex];
        }


        //Constants.DATABASE_NAME = Constants.Database_Path + Constants.dbList[dbIndex];


        try {
            mainDB = new DatabaseHelper(QuestionAnswerActivity.this, "");
        } catch (IOException e) {
            e.printStackTrace();
        }

        allDBData = mainDB.getAllQuestions();

        final AdView mAdView = (AdView) findViewById(R.id.activity_question_answer_adview);
        AdRequest adRequest = new AdRequest.Builder()
                //.addTestDevice("1432DF9EDEE25FAADA98CE2D4BE04650")
                .addTestDevice("1432DF9EDEE25FAADA98CE2D4BE04650")
                .build();
        mAdView.loadAd(adRequest);

        mAdView.setAdListener(new AdListener() {

            @Override
            public void onAdLoaded() {
                super.onAdLoaded();

                mAdView.setVisibility(View.VISIBLE);
            }
        });


        setUpAllControls();

        queNoCounter = 0;

        changeAndSetQuestionAnswerValue();

    }


    private void setUpAllControls(){

        questionText = (TextView) findViewById(R.id.activity_question_answer_question_text);

        answerA = (Button) findViewById(R.id.activity_question_answer_answer_a);
        answerB = (Button) findViewById(R.id.activity_question_answer_answer_b);
        answerC = (Button) findViewById(R.id.activity_question_answer_answer_c);
        answerD = (Button) findViewById(R.id.activity_question_answer_answer_d);

        prevImage = (ImageView) findViewById(R.id.activity_question_answer_prev_image);
        nextImage = (ImageView) findViewById(R.id.activity_question_answer_next_image);

        gotoBtn = (Button) findViewById(R.id.activity_question_answer_goto_btn);
        questionNoText = (TextView) findViewById(R.id.activity_question_answer_question_number_text);


        answerA.setOnClickListener(this);
        answerB.setOnClickListener(this);
        answerC.setOnClickListener(this);
        answerD.setOnClickListener(this);

        prevImage.setOnClickListener(this);
        nextImage.setOnClickListener(this);

        gotoBtn.setOnClickListener(this);
    }


    private void changeAndSetQuestionAnswerValue(){
        isAnsBtnClicked = false;

        answerA.setBackgroundResource(R.drawable.rounded_corner);
        answerB.setBackgroundResource(R.drawable.rounded_corner);
        answerC.setBackgroundResource(R.drawable.rounded_corner);
        answerD.setBackgroundResource(R.drawable.rounded_corner);

        questionNoText.setText((queNoCounter+1)+"/"+allDBData.size());
        questionText.setText((queNoCounter+1)+". "+allDBData.get(queNoCounter).getQuestionName());
        //questionText.setText(queNoCounter);

        answerA.setText(allDBData.get(queNoCounter).getOptionA());
        answerB.setText(allDBData.get(queNoCounter).getOptionB());
        answerC.setText(allDBData.get(queNoCounter).getOptionC());
        answerD.setText(allDBData.get(queNoCounter).getOptionD());

        //Log.e("called", "setQuestionAnswerValue: "+allDBData.get(0).getAnswer());
    }

    private void answerClicked(int ansNo, Button selectedAnswerBtn){

        if (isAnsBtnClicked){
            return;
        }

        int currentAns = Integer.parseInt(allDBData.get(queNoCounter).getAnswer());


        if (ansNo == currentAns){
            selectedAnswerBtn.setBackgroundResource(R.drawable.rounded_corner_green);
            //selectedAnswerBtn.setBackgroundColor(Color.GREEN);
        } else {

            selectedAnswerBtn.setBackgroundResource(R.drawable.rounded_corner_red);
            if (currentAns == 1){
                this.answerA.setBackgroundResource(R.drawable.rounded_corner_green);
            } else if (currentAns == 2){
                this.answerB.setBackgroundResource(R.drawable.rounded_corner_green);
            } else if (currentAns == 3){
                this.answerC.setBackgroundResource(R.drawable.rounded_corner_green);
            } else if (currentAns == 4){
                this.answerD.setBackgroundResource(R.drawable.rounded_corner_green);
            }
        }

        isAnsBtnClicked = true;

    }

    private void goToPrev() {
        if (queNoCounter == 0){
            queNoCounter = allDBData.size()-1;
        } else {
            queNoCounter--;
        }
        changeAndSetQuestionAnswerValue();
    }

    private void goToNext() {
        if ((allDBData.size()-1) == queNoCounter){
            queNoCounter = 0;
        } else {
            queNoCounter++;
        }
        changeAndSetQuestionAnswerValue();
    }

    private void onGoToText() {

        AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(QuestionAnswerActivity.this);

        // set title
        alertDialogBuilder.setTitle("Go To Question Number");

        /*final EditText input = new EditText(QuestionAnswerActivity.this);
        LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.MATCH_PARENT,
                LinearLayout.LayoutParams.WRAP_CONTENT);
        lp.setMargins(300,300,300,300);

        input.setLayoutParams(lp);*/

        final EditText input = new EditText(QuestionAnswerActivity.this);
        input.setSingleLine();
        input.setInputType(InputType.TYPE_CLASS_NUMBER);
        FrameLayout container = new FrameLayout(QuestionAnswerActivity.this);
        FrameLayout.LayoutParams params = new  FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.leftMargin = getResources().getDimensionPixelSize(R.dimen.dialog_margin);
        params.rightMargin = getResources().getDimensionPixelSize(R.dimen.dialog_margin);
        input.setLayoutParams(params);
        container.addView(input);


        alertDialogBuilder.setView(container);

        alertDialogBuilder.setCancelable(false)
                .setPositiveButton("Go",new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog,int id) {
                        int enterdText = Integer.parseInt(input.getText().toString());

                        if (enterdText > 0 && enterdText <= allDBData.size()){

                            queNoCounter = enterdText -1;

                            changeAndSetQuestionAnswerValue();

                            dialog.cancel();
                        } else {
                            Toast.makeText(QuestionAnswerActivity.this, "Please select between 1 to "+(allDBData.size()),Toast.LENGTH_LONG).show();
                        }

                        // if this button is clicked, close
                        // current activity

                        //MainActivity.this.finish();

                    }
                })
                .setNegativeButton("Cancle",new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        // if this button is clicked, just close
                        // the dialog box and do nothing
                        dialog.cancel();
                    }
                });

        // create alert dialog
        AlertDialog alertDialog = alertDialogBuilder.create();

        // show it
        alertDialog.show();
    }


    @Override
    public void onClick(View view) {

        switch (view.getId()){

            case R.id.activity_question_answer_answer_a:{
                answerClicked(1, answerA);
                break;
            }
            case R.id.activity_question_answer_answer_b:{
                answerClicked(2, answerB);
                break;
            }
            case R.id.activity_question_answer_answer_c:{
                answerClicked(3, answerC);
                break;
            }
            case R.id.activity_question_answer_answer_d:{
                answerClicked(4, answerD);
                break;
            }
            case R.id.activity_question_answer_prev_image:{
                goToPrev();
                break;
            }
            case R.id.activity_question_answer_next_image:{
                goToNext();
                break;
            }case R.id.activity_question_answer_goto_btn:{
                onGoToText();
                break;
            }

        }
    }


    @Override
    public boolean onCreateOptionsMenu(final Menu menu) {
        getMenuInflater().inflate(R.menu.question_answer_activity_menu, menu);
//        final MenuItem searchItem = menu.findItem(R.id.action_search);
        final MenuItem action_share = menu.findItem(R.id.action_share);

        action_share.setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            @Override
            public boolean onMenuItemClick(MenuItem item) {

                String shareBody = "Give me answer of this question"+ "\n \n" +allDBData.get(queNoCounter).getQuestionName()+ "\n \nA. " +
                        allDBData.get(queNoCounter).getOptionA() + "\nB. " +
                        allDBData.get(queNoCounter).getOptionB() + "\nC. " +
                        allDBData.get(queNoCounter).getOptionC() + "\nD. " +
                        allDBData.get(queNoCounter).getOptionD()  + "\n \n \nCheckout this Application for GK :\n"
                        + "https://play.google.com/store/apps/details?id="+Constants.PACKAGE_NAME;

                Intent sharingIntent = new Intent(android.content.Intent.ACTION_SEND);
                sharingIntent.setType("text/plain");
                sharingIntent.putExtra(android.content.Intent.EXTRA_SUBJECT, "Share News");
                sharingIntent.putExtra(android.content.Intent.EXTRA_TEXT, shareBody);
                startActivity(Intent.createChooser(sharingIntent, "Share Using"));

                return false;
            }
        });

        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case android.R.id.home:
                finish();
                break;
        }

        return super.onOptionsItemSelected(item);
    }


    @Override
    public void onBackPressed() {
        super.onBackPressed();
    }
}
